@@ -6,7 +6,7 @@ from .experiment_file import experiment_file_option
 from .experiment_id import experiment_id_argument
 from .identifiers import identifiers_argument, identifiers_help
 from .load_yaml import load_yaml_callback
-from .project import project_option
+from .project import project_option, project_name_option
 from .provider import provider_option
 from .run_file import run_file_option
 from .source_file import source_file_option
