@@ -12,5 +12,5 @@ source_file_option = click.option(
   '--source-file',
   type=click.Path(exists=True),
   callback=file_contents,
-  help="A file containing the source code for your run. The contents will be uploaded to your run.",
+  help="A file containing the source code for your run. The contents will be stored as data on your run.",
 )
