@@ -14,22 +14,11 @@ class BoundApiEndpoint(object):
     conn = self._bound_resource._resource._conn
     raw_response = None
 
-    call = None
-    if self._endpoint._method == 'GET':
-      call = conn._get
-    elif self._endpoint._method == 'POST':
-      call = conn._post
-    elif self._endpoint._method == 'PUT':
-      call = conn._put
-    elif self._endpoint._method == 'DELETE':
-      call = conn._delete
+    raw_response = conn._request(self._endpoint._method, url, params)
 
-    raw_response = call(url, params)
-
-    if self._endpoint._response_cls is not None:
+    if raw_response is not None and self._endpoint._response_cls is not None:
       return self._endpoint._response_cls(raw_response, self, params)
-    else:
-      return None
+    return None
 
   def __call__(self, **kwargs):
     return self.call_with_params(kwargs)
