@@ -1,12 +1,19 @@
+import http
+
+import click
+
 from sigopt.validate import validate_experiment_input
 
-from .defaults import check_valid_project_id, ensure_project_exists, get_default_project
+from .defaults import check_valid_project_id, ensure_project_exists, get_default_project, get_client_id
 from .interface import get_connection
-from .logging import print_logger
+from .sigopt_logging import print_logger
 from .run_factory import BaseRunFactory
+from .exception import ProjectNotFoundException
 from .experiment_context import ExperimentContext
 from .validate.keys import PROJECT_KEY, RUNS_ONLY_KEY
 from .run_context import global_run_context
+from .utils import batcher
+from .exception import ApiException, ConflictingProjectException
 
 
 class SigOptFactory(BaseRunFactory):
@@ -47,6 +54,28 @@ class SigOptFactory(BaseRunFactory):
       experiment.id,
     )
 
+  def create_project(self, id_=None, name=None):
+    if id_ is not None:
+      self.set_project(id_)
+    if name is None:
+      name = self.project
+    client_id = get_client_id(self.connection)
+    try:
+      project = self.connection.clients(client_id).projects().create(id=self.project, name=name)
+    except ApiException as e:
+      if e.status_code == http.HTTPStatus.CONFLICT:
+        raise ConflictingProjectException(self.project) from e
+      raise
+    self._client_id = client_id
+    self._assume_project_exists = True
+    return project
+
+  def set_up_cli(self):
+    try:
+      self.ensure_project_exists()
+    except ProjectNotFoundException as pnfe:
+      raise click.ClickException(pnfe) from pnfe
+
   def ensure_project_exists(self):
     # if we have already ensured that the project exists then we can skip this step in the future
     if not self._assume_project_exists:
@@ -61,6 +90,16 @@ class SigOptFactory(BaseRunFactory):
     run_context = self.run_context_class(connection, run, global_run_context.params)
     return run_context
 
+  def upload_runs(self, runs, max_batch_size=10000):
+    connection = self.connection
+    client_id, project_id = self.ensure_project_exists()
+    result = []
+    for batch in batcher(runs, max_batch_size):
+      result.extend(
+        connection.clients(client_id).projects(project_id).training_runs().create_batch(runs=batch, fields='id').data
+      )
+    return result
+
   def create_prevalidated_experiment(self, validated_body):
     connection = self.connection
     client_id, project_id = self.ensure_project_exists()
@@ -96,8 +135,8 @@ class SigOptFactory(BaseRunFactory):
       )
     return ExperimentContext(experiment, connection=connection)
 
-  def archive_experiment(self, experiment_id):
-    self.connection.experiments(experiment_id).delete()
+  def archive_experiment(self, experiment_id, include_runs=False):
+    self.connection.experiments(experiment_id).delete(include_runs="true" if include_runs else "false")
 
   def unarchive_experiment(self, experiment_id):
     self.connection.experiments(experiment_id).update(state="active")
