@@ -1,4 +1,6 @@
+import backoff
 import requests
+from http import HTTPStatus
 
 from .compat import json as simplejson
 from .config import config
@@ -50,7 +52,7 @@ class Requestor(object):
   def delete(self, url, params=None, json=None, headers=None):
     return self.request('delete', url=url, params=params, json=json, headers=headers)
 
-  def request(self, method, url, params=None, json=None, headers=None, user_agent=None):
+  def _request(self, method, url, params, json, headers, user_agent):
     headers = self._with_default_headers(headers, user_agent)
     try:
       caller = (self.session or requests)
@@ -74,6 +76,16 @@ class Requestor(object):
       message.append('')
       message.append(str(rqe))
       raise ConnectionException('\n'.join(message)) from rqe
+    return response
+
+  def request(self, method, url, params=None, json=None, headers=None, user_agent=None):
+    retry = backoff.on_predicate(
+      backoff.expo,
+      lambda response: response.status_code == HTTPStatus.TOO_MANY_REQUESTS,
+      max_time=self.timeout,
+      jitter=backoff.full_jitter,
+    )
+    response = retry(self._request)(method, url, params, json, headers, user_agent)
     return self._handle_response(response)
 
   def _with_default_headers(self, headers, user_agent):
